var searchData=
[
  ['octave_5fset_5fimmutable',['octave_set_immutable',['../plplot__octaveOCTAVE__wrap_8cxx.html#adf5ca0c253f8f1175ad6ec3198339e12',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['octave_5fswig_5fpacked',['octave_swig_packed',['../classoctave__swig__packed.html#a7fb233507a6efc83a4bebc2dd2f8ad34',1,'octave_swig_packed']]],
  ['octave_5fswig_5fref',['octave_swig_ref',['../classoctave__swig__ref.html#ade9ab737a9d019a2edc7d238442f1354',1,'octave_swig_ref']]],
  ['octave_5fswig_5ftype',['octave_swig_type',['../classoctave__swig__type.html#a0f52916c2d5f9d56f96fe3d7b2c5fb3b',1,'octave_swig_type::octave_swig_type(const octave_swig_type &amp;x)'],['../classoctave__swig__type.html#a66c9d24f4c10cf5f1ba4375467fb4b69',1,'octave_swig_type::octave_swig_type(void *_ptr=0, const swig_type_info *_type=0, int _own=0, bool _always_static=false)']]],
  ['octave_5fvalue_5fref',['octave_value_ref',['../structoctave__value__ref.html#ab8bd77f03124b6ff2dce4d814c69f933',1,'octave_value_ref']]],
  ['on_5fright_5fside',['on_right_side',['../delaunay_8c.html#a0fd0f63831b1479599a0dd82bdfede8e',1,'delaunay.c']]],
  ['oncreate',['OnCreate',['../classwxPLplotwindow.html#a09fe8cf92d3ccae0e58f1dd92051d684',1,'wxPLplotwindow']]],
  ['onerase',['OnErase',['../classwxPLplotwindow.html#ad184b76db6081d2e4bdde5f6854eca7c',1,'wxPLplotwindow']]],
  ['onew2b_5fget',['ONEW2B_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a48108b997959f8917ea9405eeba4a127',1,'plplot::core::plplotjavacJNI']]],
  ['onew2d_5fget',['ONEW2D_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#ac60c7e39ad16613ba0a03163d40943c7',1,'plplot::core::plplotjavacJNI']]],
  ['onpaint',['OnPaint',['../classwxPLplotwindow.html#a53f657e3771b953d80ad077e7add1594',1,'wxPLplotwindow']]],
  ['onsize',['OnSize',['../classwxPLplotwindow.html#aa4b386e34069cb93a2c47d9e986eb8bb',1,'wxPLplotwindow']]],
  ['open_5fspan_5ftag',['open_span_tag',['../cairo_8c.html#a867093342214820735c9ba2639a61163',1,'cairo.c']]],
  ['opendir',['opendir',['../dirent__msvc_8h.html#a56af8d3cfb4a2b2f44e20b276db71f2a',1,'dirent_msvc.h']]],
  ['openlib',['openlib',['../classplplot_1_1core_1_1PLStream.html#ab60146b9e58139fa4042edc86d25b5c0',1,'plplot::core::PLStream']]],
  ['openlink',['Openlink',['../plframe_8c.html#aeebefaec04e51ed012f1a228da6fcad0',1,'Openlink(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#a5d5a15109cfd92b30de260d8859c4659',1,'Openlink(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#a7005483db95c285a3bde1d0f83afca38',1,'Openlink(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#a3b7649b3ec8d467411ab7b7594d82523',1,'Openlink(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
  ['operator_20octave_5fvalue',['operator octave_value',['../structoctave__value__ref.html#ab201e4e88c3cdab9759a151e8ab0bf55',1,'octave_value_ref']]],
  ['operator_28_29',['operator()',['../classRand.html#af26fbf390a6ee90604189e59ec910757',1,'Rand::operator()()'],['../classContourable__Data.html#a9b3d26312fbe5f9052f150f10f4e0041',1,'Contourable_Data::operator()()'],['../classCoord__2d.html#ac7363a2e45f0a6ab1f82371fb3beb9d9',1,'Coord_2d::operator()()']]],
  ['operator_2a',['operator*',['../structoctave__value__ref.html#aab197384a2c36352f58c2749fd253c13',1,'octave_value_ref']]],
  ['operator_3d',['operator=',['../classPLNamedMutexLocker.html#ae51462bb922767382a097b88b399ea7a',1,'PLNamedMutexLocker::operator=()'],['../classplstream.html#a2dbfc7548479908d27dab94893aacae1',1,'plstream::operator=()'],['../classoctave__swig__type.html#ab6d91d397ec8158313e7fcca46343a95',1,'octave_swig_type::operator=()']]],
  ['opt_5fa',['opt_a',['../plargs_8c.html#a22b9e603df78ad9759048b0b5aa97b97',1,'opt_a(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a031c7b3bf488e965d3f02edee2e6d4d0',1,'opt_a(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fauto_5fpath',['opt_auto_path',['../plargs_8c.html#a433d97e5b433721cc4f750dcce602723',1,'opt_auto_path(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a6d9a246989841e6394804a3b5b0085fd',1,'opt_auto_path(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fbg',['opt_bg',['../plargs_8c.html#aea3d7fbcbd122cd689a9ee129db5285a',1,'opt_bg(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a3801db071a1f029778ba3acfd1d171b0',1,'opt_bg(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fbufmax',['opt_bufmax',['../plargs_8c.html#a5c0c2b0d3908a9a773afbcacdf5f02d2',1,'opt_bufmax(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a6e931463f4554c701ea1dfde5ef83b81',1,'opt_bufmax(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fcmap0',['opt_cmap0',['../plargs_8c.html#a73d71aa3dda72e024760c58c80866192',1,'opt_cmap0(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a7093b94c507be936dbe1fe443c4f775f',1,'opt_cmap0(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fcmap1',['opt_cmap1',['../plargs_8c.html#a329e90f332db409bd2cc112701492ed2',1,'opt_cmap1(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a48d16285e595fe717cc744621dce4c07',1,'opt_cmap1(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fdb',['opt_db',['../plargs_8c.html#a60b4c1e15df0e594d885f0d688734ea9',1,'opt_db(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#ae36ded1c0479e21ca4b9e3140838bad4',1,'opt_db(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fdebug',['opt_debug',['../plargs_8c.html#a5d840a43d2647b3906d3f6d6cd06795b',1,'opt_debug(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#aea2c4067f497162df2ded4038b2463fa',1,'opt_debug(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fdev',['opt_dev',['../plargs_8c.html#a5c2cd98bf5e69d2ae34d6a7f96fe780f',1,'opt_dev(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a90da905d1de96a446f12a95c95be795c',1,'opt_dev(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fdev_5fcompression',['opt_dev_compression',['../plargs_8c.html#a467eea7dfebb391d25f7d04875010e1e',1,'opt_dev_compression(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a5668b2f91e4ac3afafdc31aee3046d58',1,'opt_dev_compression(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fdpi',['opt_dpi',['../plargs_8c.html#ad59c29a9f3ce0a3fd369841224660f81',1,'opt_dpi(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#aede890282a04cb6611c7bdd5e866d386',1,'opt_dpi(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fdrvopt',['opt_drvopt',['../plargs_8c.html#ac69bb65573b70926a22e1e3e91aa667a',1,'opt_drvopt(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a87286c8a8503175b16de80db684c3d29',1,'opt_drvopt(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5feofill',['opt_eofill',['../plargs_8c.html#a43fcb77df0e18802fa97667f5c0353d2',1,'opt_eofill(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a1a49b696e1c67cb86df30f8d1d7e0aba',1,'opt_eofill(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ffam',['opt_fam',['../plargs_8c.html#af73010cb5a6a4de1861dad372f9c638a',1,'opt_fam(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#af35e3282d6d504ba715501717542292d',1,'opt_fam(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ffbeg',['opt_fbeg',['../plargs_8c.html#a346c3c3bad4c5720fe183ad3c0f7ba8f',1,'opt_fbeg(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#af20c352521f16f7a96d191506c14081d',1,'opt_fbeg(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ffflen',['opt_fflen',['../plargs_8c.html#a2ef82a482c5929ad0f2b7278b7efb69c',1,'opt_fflen(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a1c77c3252e1bf33ab6d026e6f584f8e2',1,'opt_fflen(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ffinc',['opt_finc',['../plargs_8c.html#af012c1aa10aa5b866726f9a914c6b907',1,'opt_finc(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a82ba88ca8174d9766e0cd670eafa5fca',1,'opt_finc(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ffreeaspect',['opt_freeaspect',['../plargs_8c.html#a3af679c429389b13f8837efff7b8a040',1,'opt_freeaspect(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#af7fccb00761dcb99cd9a765517886099',1,'opt_freeaspect(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ffsiz',['opt_fsiz',['../plargs_8c.html#a742b819c524a230e8d85c85c4323a8fb',1,'opt_fsiz(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#ac745e4714af04fbc18b87722a9ea63da',1,'opt_fsiz(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fgeo',['opt_geo',['../plargs_8c.html#a4bb5a9879e585721ffbc17390d63c60d',1,'opt_geo(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a3b3f63714d9215a5f4adf921cf4a4b57',1,'opt_geo(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fh',['opt_h',['../plargs_8c.html#a056c111e7d5ad816e6fa1ccafce74fd1',1,'opt_h(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#ac1c268dd62e1acc95f92441e634f9c86',1,'opt_h(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fhack',['opt_hack',['../plargs_8c.html#a7ca82d657bb43eb71e475957873514b5',1,'opt_hack(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a468b705b4c4a59c7e21fe3251607caeb',1,'opt_hack(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fjx',['opt_jx',['../plargs_8c.html#a2763cff54b7237ea5a439fa5f04c77bc',1,'opt_jx(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a77e085196181f7abac378e9feefce1ac',1,'opt_jx(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fjy',['opt_jy',['../plargs_8c.html#a4876a664990d0d54e7cc5d566fb7de2e',1,'opt_jy(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a1af2968fc47ea2cbbd3221c43bbd00b5',1,'opt_jy(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5flocale',['opt_locale',['../plargs_8c.html#a7d8a254eab4dc3049103dd6542590b1f',1,'opt_locale(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a77c4a1eb559afa8db5d54ad2eff43fc7',1,'opt_locale(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fmar',['opt_mar',['../plargs_8c.html#ada02ad1a23de63a8f29be293c7f81916',1,'opt_mar(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a6c3dd40f998e3542bb07aaa1101445b2',1,'opt_mar(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fmfi',['opt_mfi',['../plargs_8c.html#a0691712e0b1f0e6bce154e73384870b8',1,'opt_mfi(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#aac929d3bf383d5ed8684770d833da22e',1,'opt_mfi(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fmfo',['opt_mfo',['../plargs_8c.html#ac7a8dc3bdb60db4292bafe73e79257a3',1,'opt_mfo(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#aa4b29828c54f889d442ad57608d25680',1,'opt_mfo(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fncol0',['opt_ncol0',['../plargs_8c.html#ab448ff3aa598dadd225c9138cb870ec4',1,'opt_ncol0(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a83d65ee7aa9945a738d50ddda2a5fe20',1,'opt_ncol0(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fncol1',['opt_ncol1',['../plargs_8c.html#a471313fd89e67969eb0c637a2c8c416b',1,'opt_ncol1(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a7073df66d085f663f7138106acf939e9',1,'opt_ncol1(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fnopixmap',['opt_nopixmap',['../plargs_8c.html#afe5f63dfc95f2ac3f0cb43d218dbba2b',1,'opt_nopixmap(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#ade3fdc68c8d6d754a29a552dcad80b86',1,'opt_nopixmap(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fnp',['opt_np',['../plargs_8c.html#a3ab4abbf0e5808ee807e58e843542ad5',1,'opt_np(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a73d3604cb18348c751969639d54ca851',1,'opt_np(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fo',['opt_o',['../plargs_8c.html#af3939a237c84e94053bb947b6c83db8f',1,'opt_o(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#afeb605ff7e970d4c152c14a18fbb3366',1,'opt_o(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fori',['opt_ori',['../plargs_8c.html#ac060ad205cd1ca195eef5e8e00622996',1,'opt_ori(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a7b352b1d7b4071f790fd98b36a451de2',1,'opt_ori(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fplserver',['opt_plserver',['../plargs_8c.html#a882eadf9921e3aae3698475546d27eba',1,'opt_plserver(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a59d97bbe9b4627230590a2c1c89cad49',1,'opt_plserver(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fplwindow',['opt_plwindow',['../plargs_8c.html#ad05a22bbd6ed30eee5c2a5ba06ecfafa',1,'opt_plwindow(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#ab7782c320d943e9f1c52b12e1a7c9d68',1,'opt_plwindow(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fportrait',['opt_portrait',['../plargs_8c.html#a2b0dc8dcf79017e752de813ccc4bbe7f',1,'opt_portrait(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a36519f159de0f59425da35c2ee3abd46',1,'opt_portrait(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fpx',['opt_px',['../plargs_8c.html#a216219cfbabd3488ad68932374d0add0',1,'opt_px(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a8050d25e5544c123a6190a113fa42054',1,'opt_px(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fpy',['opt_py',['../plargs_8c.html#ae0b1fef05d6e48ad3ab9a6570d5fc0b4',1,'opt_py(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a2f5cc5922bc2eb5f7de7b3f39357a88d',1,'opt_py(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fserver_5fname',['opt_server_name',['../plargs_8c.html#a079802ce2301f7daf04f495adaffdaf2',1,'opt_server_name(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#aba6c88698b2ea40fc4cebfc6d2092c8c',1,'opt_server_name(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ftk_5ffile',['opt_tk_file',['../plargs_8c.html#ac2cc49e987db83a8ebf3634f85a22fc5',1,'opt_tk_file(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a2ddec252f09ecdd79c5b52399c0747b6',1,'opt_tk_file(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fv',['opt_v',['../plargs_8c.html#ae43a572ce862652bdddaf4db9db3a932',1,'opt_v(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a6dd108524a4ce6158d32a9c032586c70',1,'opt_v(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fverbose',['opt_verbose',['../plargs_8c.html#a8c582de79220166fe9e929ac720576a2',1,'opt_verbose(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a2937bf7b95cf26a0887c85c58600205d',1,'opt_verbose(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fwidth',['opt_width',['../plargs_8c.html#a61236c7e1a1f8b03fdb8dfbf60e412a0',1,'opt_width(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a65cf6211752a80054157629f5abf25b8',1,'opt_width(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fwplt',['opt_wplt',['../plargs_8c.html#a799666480897f06b9362fec1c6e6bc3b',1,'opt_wplt(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a4051f4ef06cfab9d71881a9a89977e9f',1,'opt_wplt(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['optusage',['OptUsage',['../classplstream.html#af54356617be65cdf161918e3430321df',1,'plstream::OptUsage()'],['../classplplot_1_1core_1_1PLStream.html#af6dd6dd9be106f386255eafc03d5c5fa',1,'plplot.core.PLStream.OptUsage()']]],
  ['orient',['orient',['../namespacePlframe.html#a82eaf9961ca3b88bf86e7c98651cdfaa',1,'Plframe.orient()'],['../plframe_8c.html#a2c41613105823b4f75157ad917403a10',1,'Orient(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#abfec6bcd9be71987ed497b7539fda236',1,'Orient(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#a6e0a64c115acc82e8c89c2b776f1c407',1,'Orient(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#af8841f8e4aaafd7f8f958211c7cb5788',1,'Orient(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
  ['originchanger',['OriginChanger',['../classOriginChanger.html#aa86ed32c05b1252ec0829eaf59fa77cf',1,'OriginChanger']]]
];
